##  Importing IT Components Using an Excel File
The inventorys import feature allows you to efficiently create multiple fact sheets at once by importing an Excel file. This is especially useful if your organization already has pre-collated enterprise architecture data.
First, use the export functionality to create a template file with columns for each required fact sheet attribute. Then, fill in or update the template with IT component information, following the formatting rules, and import the file back into the inventory. For a detailed guide, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
![Importing Fact Sheets Through an Excel File](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loioa33f992d1e6a4a82bb902510ab7effa5_LowRes.png)
Importing Fact Sheets Through an Excel File
